
/**
 * Global
 */
var amp,
		config = {
			locales: {
				en: {
					PLAYING: "playing"
				},
				es: {
					PLAYING: "jugando"
				}
			}
		},
		media = {
			source: [
				{
					type: "application/dash+xml",
					src: "http://dash.edgesuite.net/envivio/dashpr/clear/Manifest.mpd"
				}, {
					type: "application/x-mpegURL",
					src: "http://multiplatform-f.akamaihd.net/i/multi/april11/hdworld/hdworld_,512x288_450_b,.mp4.csmil/master.m3u8"
				}, {
					type: "video/f4m",
					src: "http://multiplatform-f.akamaihd.net/z/multi/april11/hdworld/hdworld_,512x288_450_b,640x360_700_b,768x432_1000_b,1024x576_1400_m,1280x720_1900_m,1280x720_2500_m,1280x720_3500_m,.mp4.csmil/manifest.f4m"
				}
			],
			autoplay: false,
			startTime: 0,
			title: "AMP Unit Tests",
			description: "AMP Unit Tests",
			duration: 108
		};

/**
 * Player Tests
 */
describe("Player", function() {
	
	beforeAll(function() {
		jasmine.DEFAULT_TIMEOUT_INTERVAL = 10000;
	});
	
	afterAll(function() {
		jasmine.DEFAULT_TIMEOUT_INTERVAL = 5000;
	});
	
	/**
	 * Defautls Tests
	 */
	describe("Defaults", function() {
	 	
	 	it("should load without error.", function(done) {
			akamai.amp.AMP.loadDefaults("../samples/samples.json", function (event) {
				expect(event).not.toBe(null);
				done();
			});
	 	});
	 	
	});
		

	/**
	 * Startup Tests
	 */
	describe("Startup", function() {
		var create = function(container, config, ready) {
			amp = akamai.amp.AMP.create(container, config, ready);
		};
		
		it("should not except an invalid container.", function() {
			expect(create.bind(null, "asdf", config)).toThrow();
			expect(create.bind(null, null, config)).toThrow();
			expect(create.bind(null, {}, config)).toThrow();
		});
		
		it("should instantiate without errors.", function(done) {
			var ready = function(event) {
				expect(event.player).toBe(amp);
				done();
			};
			expect(create.bind(null, "amp-container", config, ready)).not.toThrow();
		});
		
		it("should provide access to player on the container element.", function() {
			expect(amp.getContainer().amp).toBe(amp);
		});
	});

	/**
	 * Media Tests
	 */
	describe("Media", function() {
		
		it("should not except invalid media", function() {
			expect(amp.setMedia.bind(amp, {})).toThrow();
			expect(amp.setMedia.bind(amp, {src: ""})).toThrow();
			expect(amp.setMedia.bind(amp, {src: null})).toThrow();
			expect(amp.setMedia.bind(amp, {source: null})).toThrow();
			expect(amp.setMedia.bind(amp, {source: [{src: ""}]})).toThrow();
			expect(amp.setMedia.bind(amp, {source: [{src: null}]})).toThrow();
		});
		
		it("should accept valid media", function(done) {
			var mediachange;
			mediachange = function(event) {
				console.log("mediachange");
				amp.removeEventListener("mediachange", mediachange);
				expect(amp.getMedia()).not.toBe(null);
				done();
			};
			
			amp.addEventListener("mediachange", mediachange);
			amp.setMedia(media);
		});
		
	});

	/**
	 * Playback Tests
	 */
	describe("Playback", function() {
		
		it("should play", function(done) {
			var canplay, canplaythrough, loadedmetdata, play, playing;
			
			loadedmetdata = function(event) {
				console.log("loadedmetadata");
				amp.removeEventListener("loadedmetadata", loadedmetdata);
				expect(amp.getMedia()).not.toBe(null);
			};
			canplay = function(event) {
				console.log("canplay");
				amp.removeEventListener("canplay", canplay);
				expect(amp.getMedia()).not.toBe(null);
			};
			canplaythrough = function(event) {
				console.log("canplaythrough");
				amp.removeEventListener("canplaythrough", canplaythrough);
				expect(amp.getMedia()).not.toBe(null);
			};
			play = function(event) {
				console.log("play");
				amp.removeEventListener("play", play);
				expect(amp.getPaused()).toBe(false);
			};
			playing = function(event) {
				console.log("playing");
				amp.removeEventListener("playing", playing);
				expect(amp.getPaused()).toBe(false);
				setTimeout(done, 5);
			};
			
			amp.addEventListener("loadedmetadata", loadedmetdata);
			amp.addEventListener("canplay", canplay);
			amp.addEventListener("canplaythrough", canplaythrough);
			amp.addEventListener("play", play);
			amp.addEventListener("playing", playing);
			amp.play();
		});
		
		it("should pause", function(done) {
			var handler;
			handler = function(event) {
				amp.removeEventListener("pause", handler);
				expect(amp.getPaused()).toBe(true);
				done();
			};
			amp.addEventListener("pause", handler);
			amp.pause();
		});
		
		it("should seek", function(done) {
			var currentTime, seeked, seeking;
			currentTime = 10;
			seeking = function(event) {
				amp.removeEventListener("seeking", seeking);
				expect(amp.getSeeking()).toBe(true);
			};
			seeked = function(event) {
				amp.removeEventListener("seeked", seeked);
				expect(amp.getSeeking()).toBe(false);
				expect(amp.getCurrentTime()).toBe(currentTime);
				done();
			};
			amp.addEventListener("seeking", seeking);
			amp.addEventListener("seeked", seeked);
			amp.setCurrentTime(currentTime);
		});
		
		it("should end", function(done) {
			var ended, seeked;
			seeked = function(event) {
				amp.removeEventListener("seeked", seeked);
				expect(amp.getEnded()).toBe(false);
			};
			ended = function(event) {
				amp.removeEventListener("ended", ended);
				expect(amp.getEnded()).toBe(true);
				done();
			};
			amp.addEventListener("seeked", seeked);
			amp.addEventListener("ended", ended);
			amp.play();
			amp.setCurrentTime(amp.getDuration() - 1);
		});
	});

	/**
	 * Language Tests
	 */
	describe("Language", function() {
		
		it("should be settable", function(done) {
			var languagechange;
			languagechange = function(event) {
				amp.removeEventListener("languagechange", languagechange);
				expect(amp.l10n.PLAYING).toBe(config.locales.es.PLAYING);
				done();
			};
			expect(amp.l10n.PLAYING).toBe(config.locales.en.PLAYING);
			amp.addEventListener("languagechange", languagechange);
			amp.setLanguage("es");
		});
		
	});

	/**
	 * Binding Tests
	 */
	describe("Bindings", function() {
		
		describe("simple", function() {
			
			it("should pass through unbound values", function() {
				expect(amp.evaluateBinding("Hello World")).toBe("Hello World");
				expect(amp.evaluateBinding(null)).toBe(null);
			});
			
			it("should not except invalid bindings", function() {
				expect(amp.evaluateBinding.bind(amp, '#{asdf}')).toThrow();
			});
			
			it("should return valid JS data types", function() {
				expect(typeof amp.evaluateBinding('#{media.duration}')).toBe("number");
				expect(typeof amp.evaluateBinding('#{window.amp.play}')).toBe("function");
				expect(typeof amp.evaluateBinding('#{media}')).toBe("object");
				expect(typeof amp.evaluateBinding('#{media.src}')).toBe("string");
			});
			
			it("should evaluate all items in the player binding context", function() {
				expect(amp.evaluateBinding('#{media.src}')).toBe(amp.getSrc());
			});
		});
		
		describe("complex", function() {
			
			it("should evaluate complex bindings", function() {
				var complexBindng;
				complexBindng = 'Hello #{media.src} World';
				expect(amp.evaluateBinding(complexBindng)).not.toMatch(/Hello (null|undefined)? World/);
				expect(amp.evaluateBinding(complexBindng)).toMatch(/Hello \S+ World/);
				//expect(amp.evaluateBinding('Hello #{media.asdf} World')).toMatch(/Hello  World/);
			});
			
		});
		
	});
	
});